summaryrefslogtreecommitdiffstats
path: root/akregator/src/librss/article.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/librss/article.h')
-rw-r--r--akregator/src/librss/article.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/akregator/src/librss/article.h b/akregator/src/librss/article.h
index 611dd408..833b224a 100644
--- a/akregator/src/librss/article.h
+++ b/akregator/src/librss/article.h
@@ -90,7 +90,7 @@ namespace RSS
/**
* RSS 0.90 and upwards
- * @return The headline of this article, or TQString::null if
+ * @return The headline of this article, or TQString() if
* no headline was available.
*/
TQString title() const;
@@ -106,7 +106,7 @@ namespace RSS
/**
* RSS 0.91 and upwards
- * @return A story synopsis, or TQString::null if no description
+ * @return A story synopsis, or TQString() if no description
* was available.
*/
TQString description() const;
@@ -124,7 +124,7 @@ namespace RSS
/**
* RSS 2.0 and upwards
- * @return If this article GUID is permalink. Has no meaning when guid() is TQString::null.
+ * @return If this article GUID is permalink. Has no meaning when guid() is TQString().
*/
bool guidIsPermaLink() const;
@@ -145,10 +145,10 @@ namespace RSS
TQString meta(const TQString &key) const;
/**
* @param parent The parent widget for the KURLLabel.
* @param name A name for the widget which will be used internally.
* @return a widget (a KURLLabel in this case) for the Article.
- * This makes building a user-interface which tqcontains the
+ * This makes building a user-interface which contains the
* information in this Article object more convenient.
* The returned KURLLabel's caption will be the title(), clicking
* on it will emit the URL link(), and it has a TQToolTip attached
@@ -158,7 +158,7 @@ namespace RSS
* Note that you have to delete the KURLLabel object returned by
* this method yourself.
*/
- KURLLabel *widget(TQWidget *parent = 0, const char *name = 0) const;
+ KURLLabel *widget(TQWidget *tqparent = 0, const char *name = 0) const;
typedef TQMap<TQString, TQString> MetaInfoMap;
@@ -145,10 +145,10 @@ namespace RSS
TQString meta(const TQString &key) const;
/**
- * @param parent The parent widget for the KURLLabel.
+ * @param tqparent The tqparent widget for the KURLLabel.
* @param name A name for the widget which will be used internally.
* @return a widget (a KURLLabel in this case) for the Article.